============  ===========  =============================================================================================================================================================================================
Key           Type         Description                                                                                                                                                                                  
============  ===========  =============================================================================================================================================================================================
BINID         ``int64``    Spectrum/Bin ID number                                                                                                                                                                       
BINID_INDEX   ``int64``    Index of the spectrum in the list of provided spectra.                                                                                                                                       
REDSHIFT      ``float64``  Redshift used for shifting the passbands                                                                                                                                                     
MASK          ``bool_``    Bad-value boolean or bit mask value for the moments                                                                                                                                          
BCEN          ``float64``  Center of the blue sideband                                                                                                                                                                  
BCONT         ``float64``  Pseudo-continuum in the blue sideband                                                                                                                                                        
BCONT_ERR     ``float64``  Error in the blue-sideband pseudo-continuum                                                                                                                                                  
BCONT_MOD     ``float64``  Pseudo-continuum in the blue sideband of the best-fitting model spectrum                                                                                                                     
BCONT_CORR    ``float64``  Multiplicative correction to apply to the pseudo-continuum in the blue sideband to match the measurement for a spectrum with no Doppler broadening                                           
RCEN          ``float64``  Center of the red sideband                                                                                                                                                                   
RCONT         ``float64``  Pseudo-continuum in the red sideband                                                                                                                                                         
RCONT_ERR     ``float64``  Error in the red-sideband pseudo-continuum                                                                                                                                                   
RCONT_MOD     ``float64``  Pseudo-continuum in the red sideband of the best-fitting model spectrum                                                                                                                      
RCONT_CORR    ``float64``  Multiplicative correction to apply to the pseudo-continuum in the red sideband to match the measurement for a spectrum with no Doppler broadening                                            
MCONT         ``float64``  Interpolated continuum at the center of the main index passband (absorption-line indices only)                                                                                               
MCONT_ERR     ``float64``  Error in the continuum of the main passband                                                                                                                                                  
MCONT_MOD     ``float64``  Continuum in the main passband of the best-fitting model spectrum                                                                                                                            
MCONT_CORR    ``float64``  Multiplicative correction to apply to the continuum in the main passband to match the measurement for a spectrum with no Doppler broadening                                                  
AWGT          ``float64``  Weight needed to construct an index measured for the sum (or mean) of a set of spectra.  This identical to data pulled from either BCONT, RCONT, or MCONT, as appropriate to the calculation.
AWGT_ERR      ``float64``  Error in the aggregation weight                                                                                                                                                              
AWGT_MOD      ``float64``  Weight as measured using the best-fitting model spectrum                                                                                                                                     
AWGT_CORR     ``float64``  Multiplicative correction to apply to the weight needed to match the measurement for a spectrum with no Doppler broadening                                                                   
INDX          ``float64``  Index measurement for the observed spectrum.  Absorption lines are measured using the definition in Worthey et al. (1994)                                                                    
INDX_ERR      ``float64``  Error in the spectral index                                                                                                                                                                  
INDX_MOD      ``float64``  Spectral index as measured using the best-fitting model spectrum                                                                                                                             
INDX_CORR     ``float64``  Index correction needed to match the measurement for a spectrum with no Doppler broadening                                                                                                   
INDX_BF       ``float64``  Index measurement for the observed spectrum.  Absorption lines are measured using the definition used by Burstein et al. (1984) and Faber et al. (1985); see also Faber et al. (1977)        
INDX_BF_ERR   ``float64``  Error in the spectral index                                                                                                                                                                  
INDX_BF_MOD   ``float64``  Spectral index as measured using the best-fitting model spectrum                                                                                                                             
INDX_BF_CORR  ``float64``  Index correction needed to match the measurement for a spectrum with no Doppler broadening                                                                                                   
============  ===========  =============================================================================================================================================================================================

